#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bifunctors
version:              5.5.11
visibility:           public
id:                   bifunctors-5.5.11-I8MVLGtsycGakOlqrC4OY
key:                  bifunctors-5.5.11-I8MVLGtsycGakOlqrC4OY
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  f19afda9c418057001b228bd20e693f0
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs:          /usr/lib/ghc-8.10.5/site-local/bifunctors-5.5.11
library-dirs:         /usr/lib/ghc-8.10.5/site-local/bifunctors-5.5.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/bifunctors-5.5.11
hs-libraries:         HSbifunctors-5.5.11-I8MVLGtsycGakOlqrC4OY
includes:             bifunctors-common.h
depends:
    base-4.14.2.0 base-orphans-0.8.4-B4zsXTdczgN9mmNUwgnmE3
    comonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL containers-0.6.4.1
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-5X2XqBZ7rCLBwJXut5dQBZ transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

